@@ -192,7 +192,8 @@ syy= sum(yy^2)
 
   scor <- temp/syy
   b0hat <- mx-scor*my
-  xhat <- matrix(b0hat,nrow=nrow(x),ncol=ncol(x))+y*matrix(scor,nrow=nrow(x),ncol=ncol(x))
+  ym=matrix(y,nrow=nrow(x),ncol=ncol(x),byrow=T)
+  xhat <- matrix(b0hat,nrow=nrow(x),ncol=ncol(x))+ym*matrix(scor,nrow=nrow(x),ncol=ncol(x))
   sigma <- sqrt(rowSums((x-xhat)^2)/(ncol(xhat)-2))
   sd <- sigma/sqrt(syy)
   tt <- scor/(sd+s0)
